import { defHttp } from '@/utils/http/axios';
import { LoginParams, LoginResultModel, GetUserInfoModel } from './model/userModel';
import Qs from 'qs';
import { ErrorMessageMode } from '#/axios';
import { encrypt } from '@/utils/jsencrypt.js'
import {ContentTypeEnum} from "@/enums/httpEnum";

enum Api {
  Login = '/auth/login',
  Logout = '/logout',
  GetUserInfo = '/system/user/getInfo',
  GetPermCode = '/getPermCode',
  TestRetry = '/testRetry',
}

/**
 * @description: user login api
 */
export function loginApi(params: LoginParams, mode: ErrorMessageMode = 'modal') {
  return defHttp.post<any>(
    {
      url: Api.Login,
      data: Qs.stringify({
        sign: encrypt(params)
      }),
      headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: getUserInfo
 */
export function getUserInfo(type) {
  return defHttp.get<any>({ url: Api.GetUserInfo, params:{type:type} }, { errorMessageMode: 'none' });
}

export function getPermCode() {
  return defHttp.get<string[]>({ url: Api.GetPermCode });
}

export function doLogout() {
  return defHttp.get({ url: Api.Logout });
}

export function testRetry() {
  return defHttp.get(
    { url: Api.TestRetry },
    {
      retryRequest: {
        isOpenRetry: true,
        count: 5,
        waitTime: 1000,
      },
    },
  );
}
