import {
  AccountParams,
  DeptListItem,
  MenuParams,
  RoleParams,
  RolePageParams,
  MenuListGetResultModel,
  DeptListGetResultModel,
  AccountListGetResultModel,
  RolePageListGetResultModel,
  RoleListGetResultModel,
} from '../../demo/model/systemModel';
import { defHttp } from '@/utils/http/axios';
import { UploadFileParams } from '#/axios';
import { AxiosProgressEvent } from 'axios';
import { UploadApiResult } from '@/api/sys/model/uploadModel';

enum Api {
  addUser = '/system/user/add',
  userDetail = '/system/user/',
  updataApi = '/system/user/update',
  changeFlag = '/system/user/changeStatus',
  AccountList = '/system/user/list',
  deleteUserApi = '/system/user/deleteLogical/',
  resetUserPwdApi = '/system/user/resetPassword',
  exportApi = '/system/user/export',
  importTemplateApi = '/system/user/importTemplate',
  userImportApi = '/system/user/importExcel',
}

/** 用户列表查询*/
export const getAccountList = (params: AccountParams) =>
  defHttp.get<AccountListGetResultModel>({ url: Api.AccountList, params });

/** 用户列表导出*/
export const exportUserList = (params: AccountParams) =>
  defHttp.get<AccountListGetResultModel>({ url: Api.exportApi, params, responseType: 'blob' });

/** 用户导入模板下载*/
export const downImportTemplate = () =>
  defHttp.get<any>({ url: Api.importTemplateApi, responseType: 'blob' });

/** 用户导入*/
export const userImport = (
  params: UploadFileParams,
  onUploadProgress: (progressEvent: AxiosProgressEvent) => void,
) =>
  defHttp.uploadFile<UploadApiResult>(
    {
      url: Api.userImportApi,
      onUploadProgress,
    },
    params,
  );
/** 用户删除*/
export const deleteUser = (params?: any) =>
  defHttp.delete<any>({ url: Api.deleteUserApi + params.id });

/** 用户add*/
export const addUserApi = (params: any) =>
  defHttp.post({
    url: Api.addUser,
    params: params,
    // headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
  });

/** 获取用户详情信息*/
export const UserDetailApi = (params: any) => defHttp.get<any>({ url: Api.userDetail + params });

/** 用户信息编辑*/
export const UserUpdataApi = (params: any) =>
  defHttp.put<any>({
    url: Api.updataApi,
    params: params,
  });

/** 用户密码重置*/
export const resetUserPwd = (params: any) =>
  defHttp.put<any>({
    url: Api.resetUserPwdApi,
    params: params,
  });

/** 用户状态编辑*/
export const changeFlagApi = (params: any) =>
  defHttp.put<any>({
    url: Api.changeFlag,
    params: params,
    // headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
  });
